summaryrefslogtreecommitdiff
path: root/core
authordrw <drw>2005-03-16 17:45:28 (UTC)
committer drw <drw>2005-03-16 17:45:28 (UTC)
commit44209002d51056e0d198b63463ebc686b41e8cd8 (patch) (side-by-side diff)
treed61069f16d8382959065cf7fe43d4e68ad448daf /core
parentd16a2a4e0617f21cba0e399dbe5ffa17d76886b9 (diff)
downloadopie-44209002d51056e0d198b63463ebc686b41e8cd8.zip
opie-44209002d51056e0d198b63463ebc686b41e8cd8.tar.gz
opie-44209002d51056e0d198b63463ebc686b41e8cd8.tar.bz2
Fixed: 1. Category handling - all other apps and libopie2 use -1 for unfiled and 0 for all, addressbook flipped them, 2. Letter picker record selection, 3. sort resulting records after letter picker selected them
Diffstat (limited to 'core') (more/less context) (ignore whitespace changes)
-rw-r--r--core/pim/addressbook/abtable.cpp1
-rw-r--r--core/pim/addressbook/abview.cpp44
-rw-r--r--core/pim/addressbook/addressbook.cpp7
3 files changed, 25 insertions, 27 deletions
diff --git a/core/pim/addressbook/abtable.cpp b/core/pim/addressbook/abtable.cpp
index 0be7d1a..49e66ad 100644
--- a/core/pim/addressbook/abtable.cpp
+++ b/core/pim/addressbook/abtable.cpp
@@ -161,3 +161,2 @@ void AbTable::setContacts( const Opie::OPimContactAccess::List& viewList )
- Opie::OPimContactAccess::List::Iterator it;
setNumRows( m_viewList.count() );
diff --git a/core/pim/addressbook/addressbook.cpp b/core/pim/addressbook/addressbook.cpp
index 6984501..faae0a9 100644
--- a/core/pim/addressbook/addressbook.cpp
+++ b/core/pim/addressbook/addressbook.cpp
@@ -856,4 +856,7 @@ void AddressbookWindow::slotSetCategory( const QString &category )
// Tell the view about the selected category
- m_config.setCategory( category );
- m_abView -> setShowByCategory( category );
+ QString cat = category;
+ if ( cat == tr( "All" ) )
+ cat = QString::null;
+ m_config.setCategory( cat );
+ m_abView -> setShowByCategory( cat );
}
diff --git a/core/pim/addressbook/abview.cpp b/core/pim/addressbook/abview.cpp
index 6be19f8..34035fd 100644
--- a/core/pim/addressbook/abview.cpp
+++ b/core/pim/addressbook/abview.cpp
@@ -44,3 +44,3 @@ AbView::AbView ( QWidget* parent, const QValueList<int>& ordered ):
m_inPersonal( false ),
- m_curr_category( -1 ),
+ m_curr_category( 0 ),
m_curr_View( TableView ),
@@ -159,16 +159,5 @@ void AbView::load()
- if ( m_curr_category == 0 ) {
- // Show unfiled
- m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimContactAccess::DoNotShowWithCategory, 0 );
- } else if ( m_curr_category != -1 ){
- // Just show selected category
- m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimBase::FilterCategory, m_curr_category );
- } else {
- // Show all categories
- m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
- Opie::OPimBase::FilterOff, 0 );
- }
-
+ m_list = m_contactdb->sorted( true, Opie::OPimContactAccess::SortFileAsName,
+ Opie::OPimContactAccess::FilterCategory, m_curr_category );
+
// if ( m_curr_category != -1 )
@@ -201,5 +190,7 @@ void AbView::setShowByCategory( const QString& cat )
- // All (cat == NULL) will be stored as -1
- if ( cat.isNull() )
- intCat = -1;
+ // Unfiled will be stored as -1
+ if ( cat == tr( "Unfiled" ) )
+ intCat = -1;
+ else if ( cat.isNull() )
+ intCat = 0;
else
@@ -214,5 +205,5 @@ void AbView::setShowByCategory( const QString& cat )
emit signalClearLetterPicker();
-
load();
}
+ m_curr_category = intCat;
@@ -247,3 +238,3 @@ void AbView::setShowByLetter( char c, AbConfig::LPSearchMode mode )
// ignore the request ..
- if ( ! m_contactdb->hasQuerySettings( Opie::OPimContactAccess::WildCards |
+ if ( ! m_contactdb->hasQuerySettings( Opie::OPimContactAccess::WildCards |
Opie::OPimContactAccess::IgnoreCase ) ){
@@ -267,4 +258,9 @@ void AbView::setShowByLetter( char c, AbConfig::LPSearchMode mode )
m_list = m_contactdb->queryByExample( query, Opie::OPimContactAccess::WildCards | Opie::OPimContactAccess::IgnoreCase );
- if ( m_curr_category != -1 )
+
+ if ( m_curr_category != 0 )
clearForCategory();
+
+ // Sort filtered results
+ m_list = m_contactdb->sorted( m_list, true, Opie::OPimContactAccess::SortFileAsName,
+ Opie::OPimContactAccess::FilterCategory, m_curr_category );
m_curr_Contact = 0;
@@ -380,3 +376,3 @@ void AbView::slotDoFind( const QString &str, bool caseSensitive, bool useRegExp,
// we will not have a lot of matching entries..
- if ( m_curr_category != -1 )
+ if ( m_curr_category != 0 )
clearForCategory();
@@ -420,3 +416,3 @@ void AbView::clearForCategory()
Opie::OPimContactAccess::List allList = m_list;
- if ( m_curr_category != -1 ){
+ if ( m_curr_category != 0 ){
for ( it = allList.begin(); it != allList.end(); ++it ){
@@ -443,3 +439,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
returnMe = false;
- if ( cats.count() == 0 && category == 0 )
+ if ( cats.count() == 0 && category == -1 )
// Contacts with no category will just shown on "All" and "Unfiled"